==> open-cluster-management-policy-model-5.12.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/DetailsPerTemplate.java <==

package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "compliant",
    "history",
    "templateMeta"
})
@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@ToString
@EqualsAndHashCode
@Setter
@Accessors(prefix = {
    "_",
    ""
})
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class DetailsPerTemplate implements KubernetesResource
{

    @JsonProperty("compliant")
    private String compliant;
    @JsonProperty("history")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<ComplianceHistory> history = new ArrayList<ComplianceHistory>();
    @JsonProperty("templateMeta")
    private io.fabric8.kubernetes.api.model.ObjectMeta templateMeta;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public DetailsPerTemplate() {
    }

    /**
     * 
     * @param compliant
     * @param history
     * @param templateMeta
     */
    public DetailsPerTemplate(String compliant, List<ComplianceHistory> history, io.fabric8.kubernetes.api.model.ObjectMeta templateMeta) {
        super();
        this.compliant = compliant;
        this.history = history;
        this.templateMeta = templateMeta;
    }

    @JsonProperty("compliant")
    public String getCompliant() {
        return compliant;
    }

    @JsonProperty("compliant")
    public void setCompliant(String compliant) {
        this.compliant = compliant;
    }

    @JsonProperty("history")
    public List<ComplianceHistory> getHistory() {
        return history;
    }

    @JsonProperty("history")
    public void setHistory(List<ComplianceHistory> history) {
        this.history = history;
    }

    @JsonProperty("templateMeta")
    public io.fabric8.kubernetes.api.model.ObjectMeta getTemplateMeta() {
        return templateMeta;
    }

    @JsonProperty("templateMeta")
    public void setTemplateMeta(io.fabric8.kubernetes.api.model.ObjectMeta templateMeta) {
        this.templateMeta = templateMeta;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}

==> open-cluster-management-policy-model-6.6.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1/DetailsPerTemplate.java <==

package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.Container;
import io.fabric8.kubernetes.api.model.ContainerPort;
import io.fabric8.kubernetes.api.model.EnvVar;
import io.fabric8.kubernetes.api.model.IntOrString;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.model.LabelSelector;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.model.ObjectReference;
import io.fabric8.kubernetes.api.model.PersistentVolumeClaim;
import io.fabric8.kubernetes.api.model.PodTemplateSpec;
import io.fabric8.kubernetes.api.model.ResourceRequirements;
import io.fabric8.kubernetes.api.model.Volume;
import io.fabric8.kubernetes.api.model.VolumeMount;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import lombok.EqualsAndHashCode;
import lombok.Setter;
import lombok.ToString;
import lombok.experimental.Accessors;

@JsonDeserialize(using = com.fasterxml.jackson.databind.JsonDeserializer.None.class)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "compliant",
    "history",
    "templateMeta"
})
@ToString
@EqualsAndHashCode
@Setter
@Accessors(prefix = {
    "_",
    ""
})
@Buildable(editableEnabled = false, validationEnabled = false, generateBuilderPackage = false, lazyCollectionInitEnabled = false, builderPackage = "io.fabric8.kubernetes.api.builder", refs = {
    @BuildableReference(io.fabric8.kubernetes.api.model.ObjectMeta.class),
    @BuildableReference(LabelSelector.class),
    @BuildableReference(Container.class),
    @BuildableReference(PodTemplateSpec.class),
    @BuildableReference(ResourceRequirements.class),
    @BuildableReference(IntOrString.class),
    @BuildableReference(ObjectReference.class),
    @BuildableReference(LocalObjectReference.class),
    @BuildableReference(PersistentVolumeClaim.class),
    @BuildableReference(EnvVar.class),
    @BuildableReference(ContainerPort.class),
    @BuildableReference(Volume.class),
    @BuildableReference(VolumeMount.class)
})
public class DetailsPerTemplate implements KubernetesResource
{

    @JsonProperty("compliant")
    private String compliant;
    @JsonProperty("history")
    @JsonInclude(JsonInclude.Include.NON_EMPTY)
    private List<ComplianceHistory> history = new ArrayList<ComplianceHistory>();
    @JsonProperty("templateMeta")
    private io.fabric8.kubernetes.api.model.ObjectMeta templateMeta;
    @JsonIgnore
    private Map<String, Object> additionalProperties = new HashMap<String, Object>();

    /**
     * No args constructor for use in serialization
     * 
     */
    public DetailsPerTemplate() {
    }

    /**
     * 
     * @param compliant
     * @param history
     * @param templateMeta
     */
    public DetailsPerTemplate(String compliant, List<ComplianceHistory> history, io.fabric8.kubernetes.api.model.ObjectMeta templateMeta) {
        super();
        this.compliant = compliant;
        this.history = history;
        this.templateMeta = templateMeta;
    }

    @JsonProperty("compliant")
    public String getCompliant() {
        return compliant;
    }

    @JsonProperty("compliant")
    public void setCompliant(String compliant) {
        this.compliant = compliant;
    }

    @JsonProperty("history")
    public List<ComplianceHistory> getHistory() {
        return history;
    }

    @JsonProperty("history")
    public void setHistory(List<ComplianceHistory> history) {
        this.history = history;
    }

    @JsonProperty("templateMeta")
    public io.fabric8.kubernetes.api.model.ObjectMeta getTemplateMeta() {
        return templateMeta;
    }

    @JsonProperty("templateMeta")
    public void setTemplateMeta(io.fabric8.kubernetes.api.model.ObjectMeta templateMeta) {
        this.templateMeta = templateMeta;
    }

    @JsonAnyGetter
    public Map<String, Object> getAdditionalProperties() {
        return this.additionalProperties;
    }

    @JsonAnySetter
    public void setAdditionalProperty(String name, Object value) {
        this.additionalProperties.put(name, value);
    }

}
